import { TokenizeResult, TranslationMarkupTranspiler, TranspileResult, TranslationMarkupTranspilerContext } from '../translation-markup-transpiler.model';
import { TranslationMarkupRenderer } from '../translation-markup-renderer.model';
/**
 * Transpiler that substitutes a fixed token. A subclass is responsible for rendering the actual markup that will be used instead of the
 * token. This is done by providing an implementation for the abstract `createRenderer` function.
 */
export declare abstract class SubstitutionTranspiler implements TranslationMarkupTranspiler {
    /** String representing the token that will be substituted with the output of the resulting renderer. */
    private readonly substitutionToken;
    /** Object that holds the value of lazily initialized property. */
    private readonly deferred;
    /**
     * Creates a new `SubstitutionTranspiler` for the specified substitution token.
     */
    constructor(
    /** String representing the token that will be substituted with the output of the resulting renderer. */
    substitutionToken: string);
    /** @inheritdoc */
    tokenize(translation: string, offset: number): TokenizeResult | undefined;
    /** @inheritdoc */
    transpile(offset: number, { tokens }: TranslationMarkupTranspilerContext): TranspileResult | undefined;
    /**
     * Creates the renderer responsible for generating the markup that will be substituted in place of the substitution token.
     */
    protected abstract createRenderer(): TranslationMarkupRenderer;
    /** Cached value of the result of the `createRenderer` function. */
    private get renderer();
}
/**
 * Class for representing tokens that are to be replaced with the output of a specific markup renderer.
 */
export declare class SubstitutionToken {
    readonly token: string;
    /**
     *  Creates a new `SubstitutionToken` instance for the specified token.
     */
    constructor(token: string);
}
